==> mycelyso_inspector-0.0.1rc3-py3-none-any.whl: mycelyso_inspector/__init__.py <==
# -*- coding: utf-8 -*-
"""
documentation
"""

__license__ = """
Copyright (c) 2015-2017 Christian C. Sachs, Forschungszentrum Jülich GmbH.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

__author__ = "Christian C. Sachs"

__version__ = '0.1.0'  # will bump to 1.0.0 on publication

__citation__ = """
Sachs CC, Koepff J, Wiechert W, Grünberger A, Nöh K (2017)
mycelyso: Analysis of Streptomyces mycelium live cell imaging data
Submitted.
"""

__banner__ = """
  MYCElium   anaLYsis __ SOftware
  ___   __ _________ / /_ _____ ___         Developed  2015 - 2017 by
 /  ' \/ // / __/ -_) / // (_-</ _ \ __
/_/_/_/\_, /\__/\__/_/\_, /___/\___/'  \.   Christian   C.  Sachs  at
      /___/          /___/              |
            \    `           __     ,''''   Modeling&Simulation Group
             \    `----._ _,'  `'  _/
              ---'       ''      `-'        Research  Center  Juelich

If you use this software in a publication, please cite our paper:
""" + __citation__

==> mycelyso_inspector-1.0.0rc4-py3-none-any.whl: mycelyso_inspector/__init__.py <==
# -*- coding: utf-8 -*-
"""
documentation
"""

__license__ = """
Copyright (c) 2015-2018 Christian C. Sachs, Forschungszentrum Jülich GmbH.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

__author__ = "Christian C. Sachs"

__version__ = '1.0.0rc4'

__citation__ = """
Sachs CC, Koepff J, Wiechert W, Grünberger A, Nöh K (2018)
mycelyso – High-throughput analysis of Streptomyces mycelium live cell imaging data
Submitted.
"""

__banner__ = """
  MYCElium   anaLYsis __ SOftware
  ___   __ _________ / /_ _____ ___         Developed  2015 - 2018 by
 /  ' \/ // / __/ -_) / // (_-</ _ \ __
/_/_/_/\_, /\__/\__/_/\_, /___/\___/'  \.   Christian   C.  Sachs  at
      /___/          /___/              |
            \    `           __     ,''''   Modeling&Simulation Group
             \    `----._ _,'  `'  _/
              ---'       ''      `-'        Research  Centre  Juelich

               For more information visit: github.com/modsim/mycelyso
               
If you use this software in a publication, please cite our paper:
""" + __citation__
